@@ -16,38 +16,72 @@ app = typer.Typer(
 
 app = typer.Typer()
 
+
 @app.command("do")
 def edit_file(
     instruction: str = typer.Argument(
-        ..., help="Instruction to edit the file(s). Keep it short! Wrap with quotes.",
+        ...,
+        help="Instruction to edit the file(s). Keep it short! Wrap with quotes.",
     ),
     filenames: List[Path] = typer.Argument(
-        [], help="List of filenames to edit. If not provided, will prompt for input.",
+        ["#CLIPBOARD"],
+        help="List of filenames to edit. If not provided, will prompt for input.",
     ),
     backup: bool = typer.Option(
-        False, "--backup", "-b", help="Whether to create a backup of the original file(s).",
+        False,
+        "--backup",
+        "-b",
+        help="Whether to create a backup of the original file(s).",
     ),
-    yes: bool = typer.Option(False, "--yes", "-y", help="Don't ask for confirmation.",),
-    raw_code: str = typer.Option(None, "--raw-code", "-c", help="Raw code to edit. Overrides filenames"),
-    json_out: bool = typer.Option(False, "--json-out", "-j", help="Output to raw json."),
-    ):
+    yes: bool = typer.Option(
+        False,
+        "--yes",
+        "-y",
+        help="Don't ask for confirmation.",
+    ),
+    raw_code: str = typer.Option(
+        None,
+        "--raw-code",
+        "-c",
+        help="Raw code to edit. Overrides filenames. Use quotes to wrap the code.",
+    ),
+    json_out: bool = typer.Option(
+        False, "--json-out", "-j", help="Output the response in raw json format."
+    ),
+    raw_out: bool = typer.Option(
+        False,
+        "--raw-out",
+        "-r",
+        help="Output the raw 'code' from the response and exit the function.",
+    ),
+):
     """
     Do something given some code for context. Asking for documents, queries, etc. should work okay. Edits are iffy, but work a lot of the time.
-    
-    Your code better be in git before you use this.
+
+    Your code better be in git before you use this. If the instruction is one of the quick prompt options (like 'comment' or 'docs'), it will do that prompt automatically. For more info, run 'codegpt quick --help'.
 
     FILENAMES: list of filenames to edit. If not provided, will prompt for input.
     INSTRUCTION: the instruction to edit the file(s). Keep it short!
     """
 
     if not filenames and not raw_code:
-        raise typer.BadParameter("Either FILENAMES or --raw-code (-c) must be provided.")
+        raise typer.BadParameter(
+            "Either filenames or --raw-code (-c) must be provided."
+        )
+
     code = {"code": raw_code} if raw_code else files.load_text(filenames)
+
+    if instruction in prompts.prompts:
+        instruction = prompts.prompts[instruction]
+
     result = gpt.send_iffy_edit(instruction, code, yes=yes, clipboard=bool(raw_code))
 
     if json_out:
         return json.dumps(result, sort_keys=True, indent=4)
 
+    if raw_out:
+        return 'result["code"]'
+
     files.write_text(result, backup)
     typer.secho("Done!", color=typer.colors.BRIGHT_BLUE)
 
@@ -55,14 +89,26 @@ def edit_file(
 @app.command("quick")
 def quick_edit_file(
     option: str = typer.Argument(..., help=f"{{{'|'.join(prompts.prompts.keys())}}}"),
-    filenames: List[str] = typer.Argument(..., help="Enter the filenames to edit, separated by spaces"),
-        backup: bool = typer.Option(
-        False, "--backup", "-b", help="Whether to create a backup of the original file(s).",
+    filenames: List[str] = typer.Argument(
+        ..., help="Enter the filenames to edit, separated by spaces"
+    ),
+    backup: bool = typer.Option(
+        False,
+        "--backup",
+        "-b",
+        help="Whether to create a backup of the original file(s).",
+    ),
+    yes: bool = typer.Option(
+        False,
+        "--yes",
+        "-y",
+        help="Don't ask for confirmation.",
+    ),
+    raw_code: str = typer.Option(
+        None, "--raw-code", "-c", help="Raw code to edit. Overrides filenames"
     ),
-    yes: bool = typer.Option(False, "--yes", "-y", help="Don't ask for confirmation.",),
-    raw_code: str = typer.Option(None, "--raw-code", "-c", help="Raw code to edit. Overrides filenames"),
     json_out: bool = typer.Option(False, "--json", "-j", help="Output in JSON format"),
-    ):
+):
     """
     Edit a file using codegpt's built in prompts.
 
@@ -75,13 +121,19 @@ def quick_edit_file(
     - vulns - Comment in code where the vulns are if GPT sees them (iffy)
     """
     if option not in prompts.prompts:
-        raise typer.BadParameter(f"{option} is not a valid option. Must be one of {list(prompts.prompts.keys())}")
+        raise typer.BadParameter(
+            f"{option} is not a valid option. Must be one of {list(prompts.prompts.keys())}"
+        )
 
     if not filenames and not raw_code:
-        raise typer.BadParameter("Either FILENAMES or --raw-code (-c) must be provided.")
+        raise typer.BadParameter(
+            "Either FILENAMES or --raw-code (-c) must be provided."
+        )
 
     code = {"code": raw_code} if raw_code else files.load_text(filenames)
-    result = gpt.send_iffy_edit(prompts.prompts[option], code, yes=yes, clipboard=bool(raw_code))
+    result = gpt.send_iffy_edit(
+        prompts.prompts[option], code, yes=yes, clipboard=bool(raw_code)
+    )
 
     if json_out:
         return json.dumps(result, sort_keys=True, indent=4)
@@ -97,7 +149,10 @@ def config():
     """
     # check if the secret key is already set in the environment variables
     if "OPENAI_SECRET_KEY" in os.environ:
-        typer.secho("OPENAI_SECRET_KEY is already set in the environment! You probably don't need this.", typer.colors.BRIGHT_BLUE)
+        typer.secho(
+            "OPENAI_SECRET_KEY is already set in the environment! You probably don't need this.",
+            typer.colors.BRIGHT_BLUE,
+        )
     else:
         typer.confirm(
             """
